# sgGWR

## Installation
We recommend installing [JAX](https://github.com/google/jax) package for efficient computation.
To install sgGWR with JAX, please execute the following on your terminal.

```
pip install sgGWR[jax]
```

If you cannot install JAX (e.g., Windows users), you can omit `[jax]` option.

```
pip install sgGWR
```


## Reference


Please cite the following article:

- Nishi, H., & Asami, Y. (2024). Stochastic gradient geographical weighted regression (sgGWR): Scalable bandwidth optimization for geographically weighted regression. International Journal of Geographical Information Science, 38(2), 354–380. https://doi.org/10.1080/13658816.2023.2285471


